audonnx.testing
===============

.. automodule:: audonnx.testing

:mod:`audonnx.testing` provides the possibility to create
:class:`audonnx.Model` objects
with specific output shapes.

In order to use it you first have to import it explicitly:

.. code-block:: python

    import audonnx.testing

.. autosummary::
    :toctree:
    :nosignatures:

    create_model
    create_model_proto
